function [q_2,f2,q_3,beta_3]=mod_grav(q_1,f1)
%% Gravity separator model predicting 
% outlet flow rates and phase fractions

% Parameters
p = par_css(); % parameter function

% Input 
% q_1 is inlet flow rate
% f1 is inlet gas fraction


v_dot=q_1./3600;
q_g1=f1*v_dot;
q_l1=(1-f1)*v_dot;

ug=(4*q_g1)./(pi*p.D^2); % gas velocity

ul=(4*q_l1)./(pi*p.D^2); % liq velocity


% Inlet liquid entrainment E

% Calculate d32

d32=((0.0091*p.surf_t.*p.D)./(p.rho_g*ug.^2)).^0.5; % in m

% Calculate E
B=9*(p.D*ug.^3*sqrt(p.rho_l*p.rho_g)/p.surf_t).*((p.rho_g^(1-p.m)*p.mu_g^p.m)./(d32.^(1+p.m)*p.g*p.rho_l)).^(1/(2-p.m));
E=(B./(1+B))*p.Em;

% Normalized and cumulative vol distribution of entrained liquid.

% Calculate dv50 in microns;
Re=p.D.*ug*p.rho_g/p.mu_g;
dv50=0.01*(p.surf_t./(p.rho_g*ug.^2)).*(Re).^(2/3)*(p.rho_g/p.rho_l)^(-1/3)*(p.mu_g/p.mu_l)^(2/3);
dv50=dv50*10^6; 

dmax=5*dv50;
a=(dmax-dv50)/dv50;


% Separation 

% Calculate dp_cut (sizes > dp_cut are separated)
% Equating the terminal droplet and gas velocities

dp_cut=((4*18*p.mu_g*q_g1)./(pi*p.Dg^2*p.g*(p.rho_l-p.rho_g))).^0.5*10^6; 

z_cut=log(a.*dp_cut./(dmax-dp_cut));

Beta=1-0.5*(1-erf(p.delta*z_cut)); % Fraction of entrained liq remaining in exiting gas
% Separation efficiency liq
sep_eff=(1-Beta)*100;

%% Gas entrainment

% Calculate d32g

d32g=((0.0091*p.surf_t.*p.D)./(p.rho_l*ul.^2)).^0.5; % in m

% Calculate Eg
Bg=9*(p.D*ul.^3*sqrt(p.rho_l*p.rho_g)/p.surf_t).*((p.rho_l^(1-p.m)*p.mu_l^p.m)./(d32g.^(1+p.m)*p.g*p.rho_l)).^(1/(2-p.m));
Eg=(Bg./(1+Bg))*p.Em;

% Normalized and cumulative vol distribution of entrained gas.

Reg=p.D.*ul*p.rho_l/p.mu_l;
dv50g=0.01*(p.surf_t./(p.rho_l*ul.^2)).*(Reg).^(2/3)*(p.rho_l/p.rho_g)^(-1/3)*(p.mu_l/p.mu_g)^(2/3);
dv50g=dv50g*10^6; 

dmaxg=5*dv50g;
ag=(dmaxg-dv50g)/dv50g;

% Separation 
%
dp_cutg=((4*18*p.mu_l*q_l1)./(pi*p.Dg^2*p.g*(p.rho_l-p.rho_g))).^0.5*10^6; % m to microns

z_cutg=log(ag.*dp_cutg./(dmaxg-dp_cutg));

Betag=1-0.5*(1-erf(p.delta*z_cutg));

% Sep efficiency gas
sep_effg=(1-Betag)*100;

% Exiting stream flow rates and fractions

q_l2=Beta.*E.*(1-f1).*q_1; % liq out top

q_l3=(1-f1).*q_1-q_l2; % liq out bottom

q_g3=Betag.*Eg.*f1.*q_1; % gas out bottom
q_g2=f1.*q_1-q_g3; % gas out top

q_3=q_g3+q_l3; % Bottom flow rate
q_2=q_g2+q_l2; % Top flow rate

f2=q_g2./q_2; % top gas fraction

beta_3=q_l3./(q_g3+q_l3); % Bottom liq fraction


% data_grav=[q_1' E' Eg' sep_eff' sep_effg' f2' beta_3'];
% save grav.dat data_grav -ASCII

% % Plotting
% 
% figure(1)
% subplot(3,2,1)
% plot(q_1,E)
% title('Plot of liquid entrainment fraction ')
% xlabel('Inlet flow rate m3/h')
% ylabel('Entrainment fraction E')
% grid on
% 
% subplot(3,2,2)
% plot(q_1,Eg)
% title('Plot of gas entrainment fraction')
% xlabel('Inlet flow rate m3/h')
% ylabel('Entrainment fraction Eg')
% grid on
% 
% subplot(3,2,3)
% plot(q_1,sep_eff)
% title('Plot of Liquid separation efficiency ')
% xlabel('Inlet flow rate m3/h')
% ylabel('Sep. eff.-liquid')
% grid on
% 
% subplot(3,2,4)
% plot(q_1,sep_effg)
% title('Plot of gas separation efficiency ')
% xlabel('Inlet flow rate m3/hr')
% ylabel('Sep. eff.-gas')
% grid on
% 
% 
% subplot(3,2,5)
% plot(q_1,f2)
% title('Plot of gas vol fraction top exiting stream ')
% xlabel('Inlet flow rate m3/h')
% ylabel('Gas vol. fraction')
% grid on
% 
% 
% subplot(3,2,6)
% plot(q_1,beta_3)
% title('Plot of Liquid vol fraction bottom exiting stream ')
% xlabel('Inlet flow rate m3/h')
% ylabel('Liq.vol. fraction ')
% grid on
% 
% % balances
% bal_g=f1*q_1-q_g2-q_g3
% bal_l=(1-f1)*q_1-q_l2-q_l3

end